"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertValidationErrors = convertValidationErrors;
exports.validateWithTypedValidators = validateWithTypedValidators;

var _sequelizeValidateSubfields = require("sequelize-validate-subfields");

function checkPath(path) {
  for (const elem of path) {
    if (typeof elem !== 'string' && typeof elem !== 'symbol') {
      throw new Error(`invalid error path element: ${typeof elem}, ${String(elem)}`);
    }
  }

  return path;
}

function* convertValidationErrors(validation, options = {}) {
  for (let [path, message, type] of validation.errors) {
    if (options.reduxFormStyle && type.acceptsSomeCompositeTypes) {
      yield {
        path: [...checkPath(path), '_error'],
        message
      };
    } else yield {
      path: checkPath(path),
      message
    };
  }
}

function validateWithTypedValidators(type, options = {}) {
  return (0, _sequelizeValidateSubfields.validateSubfields)(function* (value) {
    const validation = typeof type === 'function' ? type(value) : type.validate(value);

    if (validation) {
      yield* convertValidationErrors(validation, options);
    }
  });
}